##  Introduction
The SAP Business Technology Platform (BTP) is becoming increasingly important in the SAP landscape. As a comprehensive offering from SAP, it provides tools, services, and technologies for developing, extending, integrating, and managing SAP applications and data. To learn more, see [SAP Business Technology Platform (BTP)![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.sap.com%2Fgermany%2Fproducts%2Ftechnology-platform.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://www.sap.com/germany/products/technology-platform.html").
In line with SAP's Clean Core and Fit2Standard concepts, customized enhancements are deployed in SAP BTP instead of directly in the SAP S/4HANA core. Because BTP is more open compared to the relatively closed SAP core system, it's essential to develop it strategically while maintaining an overview of the various solutions implemented and operated within it.
Modeling SAP BTP in SAP LeanIX brings transparency to your entire ERP landscape, including the significant SAP BTP elements your organization uses. It also helps identify potential risks to your ERP system and ensures security. By integrating SAP ERP and BTP data in SAP LeanIX, you gain a holistic view of your Intelligent Enterprise, from end-to-end processes and capabilities to implementations in S/4HANA or SAP BTP environments.
